/*--------------------------------------------------------------------------------
HELLO.C

Zdrojovy kod programu vypisuje textovy retazec Hello World! na rozhranie UART
(seriovu linku). Porjekt vyuziva MCU Intel 8052 (oproti Intel 8051 ma napr. viac
RAM pamate - 256 bajtov, co je pre programovanie v jazyku C vyhodnejsie).

Projekt predpoklada taktovanie MCU pomocou 12 MHz krystalu a pre tuto hodnotu je
nastavena prenosova rychlost rozhrania UART.

Program je mozne skompilovat a spustit pomocou rozhrania uVision
(s nainstalovanou podporou pre C51)

2017-09-19, M.D.
--------------------------------------------------------------------------------*/

#include <REG52.H>                /* deklaracia specialnych funkcnych registrov */
                                  /* pre pouzity procesor na baze jadra 8051    */

#include <stdio.h>                /* deklaracia prototypov pre I/O funkcie      */



/*
Konfiguracia serioveho portu pre 1200 baudov a 12 MHz krystal.
*/

void uart_init( void ) {
/*
Nasledujucich 6 riadkov zabezpeci vhodnu konfiguraciu perifernych obvodov
procesora Intel 8052, ktore su nevyhnutne pre seriovu komunikaciu. Presny vyznam
jednotlivych registrov je analyzovany v specializovanych predmetoch
(Mikroprocesorova technika), pre spravnu funkciu vsak postacuje pouzit uvedene
nastavenie.
*/

    SCON  = 0x50;   /* SCON: mod 1, 8-bitovy UART, povolenie prijmu             */
    TMOD |= 0x20;   /* TMOD: casovac (timer) 1, mod 2, 8-bitovy prepis (reload) */
    PCON |= 0x80;   /* SMOD: bit definuje 2-nasobnu rychlost UART rozhrania     */
    TH1   = 243;    /* TH1:  prepis hodnoty pre 4800 baudov @ 12 MHz            */
    TR1   = 1;      /* TR1:  spusti timer 1                                     */
    TI    = 1;      /* TI:   nastavi TI s cielom vyslat z UARTu prvy znak       */
}

/*
Funkcia main C. Vykon C programu zacina v tomto bode po inicializacii zasobnika
a dalsich registrov resp. pamati.
Inicializacia je definova tzv. startovacim suborom, ktory realizuje nevyhnutne
inicializacia. V pripade potreby je mozne tento subor modifikovat a doplnit
uzivatelom definovane inicializacie.
*/

void main (void) {

   uart_init();

/*
Vsimnite si, ze program nikdy nekonci (pretoze nie je vyuzity ziadny
operacny system, ktoremu by bolo mozne odovzdat riadenie).
Nekonecna slucka je jeden zo sposobov, kotre su pri vstavanych (embedded)
aplikaciach typicky vyuzivane.
*/
  while (1) {
    P1 ^= 0x01;                 /* Zmeni hodnotu na vyvode P1.0 pred vypisom */
    printf ("Hello World!\n");  /* Vypise text "Hello World!" na UART  */
  }
}


